@@ -45,3 +45,7 @@ class SettingsModelsTestCase(unittest.TestCase):
             interface="eth0",
         )
         self.assertDictEqual(ref, settings.dict())
+
+
+if __name__ == "__main__":
+    unittest.main()
